%define	major		3
%define libname		%mklibname svncpp %{major}
%define develname	%mklibname svncpp -d

Summary:	A cross-platform GUI for the Subversion concurrent versioning system
Name:		rapidsvn
Version:	0.12.1
Release:	%mkrel 9
License:	GPLv2+
Group:		Development/Tools
URL:		http://rapidsvn.tigris.org
Source0:	http://www.rapidsvn.org/download/release/%{version}/%{name}-%{version}.tar.gz
Source1:	https://raw.githubusercontent.com/RapidSVN/RapidSVN/master/doc/svncpp/svncpp.dox
Source2:	rapidsvn_logo.png
Patch1:		rapidsvn-0.12.0-linkage_fix.patch
Patch2:		rapidsvn-0.12.1-subversion1.9-private-api.patch
BuildRequires:	apache-devel >= 2.0.54
BuildRequires:	doxygen
BuildRequires:	subversion-devel >= 1.2
BuildRequires:	subversion >= 1.2
BuildRequires:	libtool >= 1.4.2
BuildRequires:	wxgtku2.8-devel
BuildRequires:	libxslt-proc
BuildRequires:	docbook-style-xsl
BuildRequires:	pkgconfig(neon) >= 0.27
BuildRequires:	imagemagick
BuildRequires:	pkgconfig(cppunit)
Requires:	subversion

%description
RapidSVN is a platform independent GUI client for the Subversion
revision system written in C++ using the wxWindows framework.

%package -n %{libname}
Summary:	RapidSVN shared SvnCpp C++ API libraries
Group:		System/Libraries

%description -n %{libname}
RapidSVN is a platform independent GUI client for the Subversion
revision system written in C++ using the wxWindows framework.

This package contains shared SvnCpp C++ API libraries for
RapidSVN.

%package -n %{develname}
Summary:	RapidSVN SvnCpp C++ API development libraries
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	libsvncpp-devel = %{version}-%{release}

%description -n %{develname}
As part of the RapidSVN effort it became clear that it would make
the code easier to update and manage if the Subversion client C
API were wrapped in C++. This is where SvnCpp comes from. Right
now it has the following aspects of the C API have been
abstracted: authentication, logging, status, notification, and
properties. SvnCpp should provide an object-oriented programming
interface to any project that uses C++ or a SWIG-compatible
language like Python or Java.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

# hack to fix: error: "configuration file svncpp.dox not found!"
cp %{SOURCE1} doc/svncpp/

cp %{SOURCE2} rapidsvn_logo.png

# The upstream Makefile is currently set up for OS/X and tries to use an old
# version of Python-native msgfmt.py, which doesn't work with Python3. Instead,
# we switch back to using the gettext version of 'msgfmt'
sed -i s/\#MSGFMT=msgfmt/MSGFMT=msgfmt/ src/locale/Makefile.am
sed -i '/MSGFMT=python/d' src/locale/Makefile.am

%build
autoreconf -vfi

export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS -std=gnu++14"

%configure \
    --enable-shared \
    --disable-static \
    --with-svn-include=%{_includedir} \
    --with-svn-lib=%{_libdir} \
    --with-xsltproc=%{_bindir}/xsltproc \
    --with-apr-config=%{_bindir}/apr-1-config \
    --with-apu-config=%{_bindir}/apu-1-config

%make_build

%install
%make_install

find %{buildroot} -name "*.la" -delete

# Mandriva Icons
install -d %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,48x48}/apps

convert rapidsvn_logo.png -resize 16x16 %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
convert rapidsvn_logo.png -resize 32x32 %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
convert rapidsvn_logo.png -resize 48x48 %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=RapidSVN
Comment=A cross-platform GUI for the Subversion concurrent versioning system
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Development;RevisionControl;
EOF

#%%{__mv} doc/svncpp/html .

%find_lang %{name}

%files -f %{name}.lang
#%%doc html AUTHORS ChangeLog NEWS README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/svncpp/
%{_libdir}/*.so


%changelog
* Tue Nov 01 2022 ghibo <ghibo> 0.12.1-9.mga9
+ Revision: 1900884
- Fix gcc12 building by forcing std=c++14
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Jan 08 2021 daviddavid <daviddavid> 0.12.1-8.mga8
+ Revision: 1669826
- fix build with python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Jul 24 2019 daviddavid <daviddavid> 0.12.1-6.mga8
+ Revision: 1423837
- add missing svncpp.dox file from upstream git to fix doc build
- fix Comment key entry from desktop file

* Sun Sep 23 2018 umeabot <umeabot> 0.12.1-5.mga7
+ Revision: 1300777
- Mageia 7 Mass Rebuild

* Wed Feb 17 2016 luigiwalser <luigiwalser> 0.12.1-4.mga6
+ Revision: 962965
- add patch from gentoo to fix build with subversion 1.9.x
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.12.1-3.mga5
+ Revision: 741720
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.12.1-2.mga5
+ Revision: 688610
- Mageia 5 Mass Rebuild

* Sun Mar 09 2014 wally <wally> 0.12.1-1.mga5
+ Revision: 601502
- clean .spec
- drop old and unneeded Mdv era provides/obsoletes
+ bersuit <bersuit>
- Update to new upstream version 0.12.1

* Sun Jan 13 2013 umeabot <umeabot> 0.12.0-8.mga3
+ Revision: 380182
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 21 2012 malo <malo> 0.12.0-7.mga3
+ Revision: 309000
- update RPM group

* Thu Jan 19 2012 fwang <fwang> 0.12.0-6.mga2
+ Revision: 198407
- drop unused patch str fmt
- drop .la file

* Fri Dec 16 2011 wally <wally> 0.12.0-5.mga2
+ Revision: 182776
- wxGTK2.8-devel BR was renamed to wxgtk2.8-devel
+ ahmad <ahmad>
- Rebuild against wxgtk2.8 with enabled catch_segvs

* Mon Mar 07 2011 mikala <mikala> 0.12.0-3.mga1
+ Revision: 66097
- Drop BuildRoot
- Remove mdk macros
- imported package rapidsvn


* Thu Dec 02 2010 Paulo Andrade <pcpa@mandriva.com.br> 0.12.0-3mdv2011.0
+ Revision: 605043
- Rebuild with apr with workaround to issue with gcc type based alias analysis

* Sun Jan 03 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.12.0-2mdv2010.1
+ Revision: 485920
- rebuild against db4.8

* Sun Nov 08 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.12.0-1mdv2010.1
+ Revision: 463068
- update to new version 0.12.0
- bump major from 1 to 3
- package translations
- spec file clean

* Sat Aug 08 2009 Oden Eriksson <oeriksson@mandriva.com> 0.10.0-2mdv2010.0
+ Revision: 411786
- rebuild

* Sun Jul 19 2009 Oden Eriksson <oeriksson@mandriva.com> 0.10.0-1mdv2010.0
+ Revision: 397469
- fix build
- 0.10.0
- rediffed one patch

* Sat Apr 11 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.8-3mdv2009.1
+ Revision: 366356
- rebuild

* Sun Mar 22 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.8-2mdv2009.1
+ Revision: 360321
- rebuilt against subversion-1.6.0

* Fri Mar 20 2009 Oden Eriksson <oeriksson@mandriva.com> 0.9.8-1mdv2009.1
+ Revision: 359228
- 0.9.8
- rediffed and dropped some patches

* Fri Feb 27 2009 Emmanuel Andry <eandry@mandriva.org> 0.9.6-6mdv2009.1
+ Revision: 345672
- use default neon
- build against db4.7

* Wed Jan 28 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.6-5mdv2009.1
+ Revision: 334705
- Patch2: fix build with -Werror=format-security (thx for patch neoclust)
- use Werror_cflags %%nil because providing a patch would took some time

* Fri Jul 11 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.6-5mdv2009.0
+ Revision: 233721
- fix linkage
- rebuild
- added a gcc43 patch from fedora

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Apr 29 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.6-3mdv2009.0
+ Revision: 199327
- fix a typo in scriplets

* Tue Apr 29 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.6-2mdv2009.0
+ Revision: 198943
- fix scriplets (#40455)

* Sat Mar 29 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.9.6-1mdv2009.0
+ Revision: 191090
- update the tarball (upstream has messed it up)
- add missing buildrequires on libcppunit-devel
- install icons into fd.o compiliant directory
- bump %%major
- do not package INSTALL file
- disable static libraries
- disable strict-aliasing as it breaks the building
- spec file clean
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Dec 26 2007 Oden Eriksson <oeriksson@mandriva.com> 0.9.4-4mdv2008.1
+ Revision: 137972
- rebuilt against openldap-2.4.7 libs

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Tue Jul 17 2007 Oden Eriksson <oeriksson@mandriva.com> 0.9.4-3mdv2008.0
+ Revision: 52874
- fix deps

  + Emmanuel Andry <eandry@mandriva.org>
    - drop debian menu


* Wed Jan 24 2007 Emmanuel Andry <eandry@mandriva.org> 0.9.4-2mdv2007.0
+ Revision: 113060
- build against wxGTK2.8 (upstream patch for this)

* Mon Dec 11 2006 Emmanuel Andry <eandry@mandriva.org> 0.9.4-1mdv2007.1
+ Revision: 94562
- New version 0.9.4

* Wed Aug 30 2006 Andreas Hasenack <andreas@mandriva.com> 0.9.3-0.r7466.3mdv2007.0
+ Revision: 58732
- bump release

* Wed Aug 30 2006 Andreas Hasenack <andreas@mandriva.com> 0.9.3-0.r7466.2mdv2007.0
+ Revision: 58726
- added docbook-style-xsl to buildrequires
- Import rapidsvn

* Mon Aug 28 2006 Emmanuel Andry <eandry@mandriva.org> 0.9.3-0.r7466.2mdv2007.0
- xdg menu

* Fri Jun 23 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.3-0.r7466.1mdv2007.0
- use a snap (r7466)

* Tue May 23 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.2-1mdk
- 0.9.2 (Major bugfixes)
- use their logo as the icon
- make it backportable (arp,apr-util)

* Mon Feb 13 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.1-2mdk
- make it buildrequire subversion so that the libsvn package is pulled in

* Sat Feb 11 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.1-1mdk
- 0.9.1
- build it against wxGTK2.6

* Mon Feb 06 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.0-4mdk
- actually make it compile, he he...

* Mon Feb 06 2006 Oden Eriksson <oeriksson@mandriva.com> 0.9.0-3mdk
- rebuild

* Wed Nov 30 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.0-2mdk
- rebuilt against openssl-0.9.8a

* Thu Oct 27 2005 Oden Eriksson <oeriksson@mandriva.com> 0.9.0-1mdk
- 0.9.0 (Major feature enhancements)
- fix deps

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 0.8.0-2mdk
- rebuilt against new openldap-2.3.6 libs

* Sun May 22 2005 Oden Eriksson <oeriksson@mandriva.com> 0.8.0-1mdk
- 0.8.0
- fix deps
- use new rpm-4.4.x pre,post magic

* Tue Feb 08 2005 Buchan Milne <bgmilne@linux-mandrake.com> 0.7.2-3mdk
- rebuild for ldap2.2_7

* Sat Feb 05 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.7.2-2mdk
- rebuilt against new openldap libs
- fix deps

* Mon Jan 17 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.7.2-1mdk
- 0.7.2
- fix deps

* Sat Jan 01 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.7.1-1mdk
- 0.7.1
- misc spec file fixes

* Wed Sep 29 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.6.0-2mdk
- make it compile on 10.0

* Thu Jul 29 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.6.0-1mdk
- 0.6.0
- reenable libtoolize

* Mon Feb 23 2004 Ben Reser <ben@reser.org> 0.5.0-1mdk
- 0.5.0 which works with subversion 0.37 and newer (including 1.0.0)
- Fix menu section.
- Drop patch for building against subversion 0.29.
- Change the name of the lib package to match the libname.

